#[non_exhaustive]pub enum Error {
NonConvergence {
op: &'static str,
},
Singular {
op: &'static str,
},
UnsupportedDType {
op: &'static str,
dtype: DType,
},
}Expand description
Failures owned by a linalg algorithm or provider boundary.
Examples
use tenferro_linalg::Error;
use tenferro_tensor::ErrorKind;
let error = Error::Singular { op: "solve" };
assert_eq!(error.kind(), ErrorKind::NumericalFailure);Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NonConvergence
The algorithm could not converge for the supplied numeric input.
Singular
The input matrix or factorization became singular.
UnsupportedDType
The selected linalg operation has no implementation for this dtype.
Implementations