pub struct EighOptions {
pub gauge: EighGauge,
pub derivative_eps: f64,
}Expand description
Options for Hermitian eigenvalue decomposition.
Examples
use tenferro_linalg::EighOptions;
let options = EighOptions::default().derivative_eps(1.0e-10);
assert_eq!(options.derivative_eps, 1.0e-10);Fields
gauge: EighGaugeEigenvector gauge convention.
derivative_eps: f64AD derivative regularization for repeated or nearly repeated eigenvalues.
Implementations
Sourceimpl EighOptions
impl EighOptions
Sourcepub fn gauge(self, gauge: EighGauge) -> Self
pub fn gauge(self, gauge: EighGauge) -> Self
Return options with the requested eigenvector gauge.
Examples
use tenferro_linalg::{EighGauge, EighOptions};
let options = EighOptions::default().gauge(EighGauge::CanonicalPivot);
assert_eq!(options.gauge, EighGauge::CanonicalPivot);Sourcepub fn derivative_eps(self, derivative_eps: f64) -> Self
pub fn derivative_eps(self, derivative_eps: f64) -> Self
Return options with an explicit derivative epsilon.
Examples
use tenferro_linalg::EighOptions;
let options = EighOptions::default().derivative_eps(1.0e-9);
assert_eq!(options.derivative_eps, 1.0e-9);Trait Implementations
Sourceimpl Clone for EighOptions
impl Clone for EighOptions
Sourcefn clone(&self) -> EighOptions
fn clone(&self) -> EighOptions
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EighOptions
impl Debug for EighOptions
Sourceimpl Default for EighOptions
impl Default for EighOptions
Sourceimpl PartialEq for EighOptions
impl PartialEq for EighOptions
Sourcefn eq(&self, other: &EighOptions) -> bool
fn eq(&self, other: &EighOptions) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for EighOptions
impl StructuralPartialEq for EighOptions