RankRevealingQrResult

Struct RankRevealingQrResult 

pub struct RankRevealingQrResult<T, M = T> {
    pub q: T,
    pub r: T,
    pub column_permutation: M,
    pub rank: M,
}
Four fixed-shape outputs of a rank-revealing QR factorization.

Q and R use T; the column permutation and numerical rank use M. For dynamic, eager, and traced tensors, T and M are the same tensor type. Typed tensors use crate::TypedRankRevealingQrResult, whose metadata tensors have scalar type i64.

Examples

use tenferro_linalg::RankRevealingQrResult;

let result = RankRevealingQrResult {
    q: "q",
    r: "r",
    column_permutation: vec![1_i64, 0],
    rank: vec![2_i64],
};
assert_eq!(result.column_permutation, [1, 0]);
assert_eq!(result.rank, [2]);

Fields

q: T

Thin orthonormal factor with shape [m, min(m, n), batch...].

r: T

Upper-trapezoidal factor with shape [min(m, n), n, batch...].

column_permutation: M

Zero-based original column at each factor column, shaped [n, batch...].

rank: M

Leading-prefix numerical rank, shaped [batch...].