pub struct SvdOptions {
pub gauge: SvdGauge,
pub derivative_eps: f64,
}Expand description
Options for singular value decomposition.
Examples
use tenferro_linalg::{SvdGauge, SvdOptions};
let options = SvdOptions::default()
.gauge(SvdGauge::CanonicalPivot)
.derivative_eps(1.0e-10);
assert_eq!(options.gauge, SvdGauge::CanonicalPivot);
assert_eq!(options.derivative_eps, 1.0e-10);Fields
gauge: SvdGaugeSingular-vector gauge convention.
derivative_eps: f64AD derivative regularization for repeated or nearly repeated singular values.
Implementations
Sourceimpl SvdOptions
impl SvdOptions
Sourcepub fn gauge(self, gauge: SvdGauge) -> Self
pub fn gauge(self, gauge: SvdGauge) -> Self
Return options with the requested singular-vector gauge.
Examples
use tenferro_linalg::{SvdGauge, SvdOptions};
let options = SvdOptions::default().gauge(SvdGauge::CanonicalPivot);
assert_eq!(options.gauge, SvdGauge::CanonicalPivot);Sourcepub fn derivative_eps(self, derivative_eps: f64) -> Self
pub fn derivative_eps(self, derivative_eps: f64) -> Self
Return options with an explicit derivative epsilon.
Examples
use tenferro_linalg::SvdOptions;
let options = SvdOptions::default().derivative_eps(1.0e-9);
assert_eq!(options.derivative_eps, 1.0e-9);Trait Implementations
Sourceimpl Clone for SvdOptions
impl Clone for SvdOptions
Sourcefn clone(&self) -> SvdOptions
fn clone(&self) -> SvdOptions
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SvdOptions
impl Debug for SvdOptions
Sourceimpl Default for SvdOptions
impl Default for SvdOptions
Sourceimpl PartialEq for SvdOptions
impl PartialEq for SvdOptions
Sourcefn eq(&self, other: &SvdOptions) -> bool
fn eq(&self, other: &SvdOptions) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for SvdOptions
impl StructuralPartialEq for SvdOptions