pub enum LinalgAdRoute {
Unsupported,
Linearize,
LinearizeThenTranspose,
LinearizeThenCustomLinearTranspose,
CustomVjp,
CustomPreferredWithLinearizeFallback,
}Expand description
Implementation route used for a user-visible AD mode.
Examples
use tenferro_linalg::{linalg_ad_support, LinalgAdOpKind, LinalgAdRoute};
let svd = linalg_ad_support(LinalgAdOpKind::Svd);
assert_eq!(svd.vjp.route, LinalgAdRoute::LinearizeThenTranspose);Variants
Unsupported
No supported route exists.
Linearize
The mode is emitted directly by the operation’s linearize rule.
LinearizeThenTranspose
Reverse mode is supported by linearizing the primal graph and then transposing that linear graph.
LinearizeThenCustomLinearTranspose
Reverse mode is supported by linearizing the primal graph and using a custom transposed-linear rule for the emitted linear operation.
CustomVjp
Reverse mode is emitted by a direct operation-specific primal VJP rule.
CustomPreferredWithLinearizeFallback
A custom VJP is preferred, with the canonical linearize-then-transpose route retained as an intentional not-applicable fallback.